@@ -107,8 +107,7 @@ def forward_dp(bp_diags, tp_diags, batch_size, input_max_len, target_max_len):
 
     fwd = tf.scan(next_state, (bp_diags[:-1, :, :-1], tp_diags), initializer=initial_alpha)
 
-    alpha = tf.transpose(
-        tf.concat([tf.expand_dims(initial_alpha, axis=0), fwd], axis=0), perm=[1, 2, 0])
+    alpha = tf.transpose(tf.concat([tf.expand_dims(initial_alpha, axis=0), fwd], axis=0), perm=[1, 2, 0])
     alpha = matrix_diag_part_v2(alpha, k=(0, target_max_len - 1), padding_value=LOG_0)
     alpha = tf.transpose(tf.reverse(alpha, axis=[1]), perm=[0, 2, 1])
 
@@ -127,17 +126,16 @@ def backward_dp(bp_diags, tp_diags, batch_size, input_max_len, target_max_len, l
         beta_t = tf.concat([x[:, :-1] + truth_probs, LOG_0 * tf.ones(shape=[batch_size, 1])], axis=1)
 
         beta_next = reduce_logsumexp(tf.stack([beta_b, beta_t], axis=0), axis=0)
-        masked_beta_next = (nan_to_zero(beta_next * tf.expand_dims(mask_s, axis=1))
-                            + nan_to_zero(x * tf.expand_dims((1.0 - mask_s), axis=1)))
-        return masked_beta_next
+        masked_beta_next = \
+            nan_to_zero(beta_next * tf.expand_dims(mask_s, axis=1)) + nan_to_zero(x * tf.expand_dims((1.0 - mask_s), axis=1))
+        return tf.reshape(masked_beta_next, shape=tf.shape(x))
 
     # Initial beta for batches.
     initial_beta_mask = tf.one_hot(logit_length - 1, depth=input_max_len + 1)
     initial_beta = tf.expand_dims(blank_sl, axis=1) * initial_beta_mask + nan_to_zero(LOG_0 * (1.0 - initial_beta_mask))
 
     # Mask for scan iterations.
-    mask = tf.sequence_mask(logit_length + label_length - 1, input_max_len + target_max_len - 2,
-                            dtype=tf.dtypes.float32)
+    mask = tf.sequence_mask(logit_length + label_length - 1, input_max_len + target_max_len - 2, dtype=tf.dtypes.float32)
     mask = tf.transpose(mask, perm=[1, 0])
 
     bwd = tf.scan(next_state, (mask, bp_diags[:-1, :, :], tp_diags), initializer=initial_beta, reverse=True)
